# -*- coding: utf-8 -*-
# @Author  : isFhy
# @Email   : fhy.sdwh@gmail.com
# @File    : custom_log.py
# @Time    : 2023/10/16 15:45
# **********************************************

"""
项目日志功能模块
"""

import logging
from logging import handlers

LOG_FILE_FMT = '[%(asctime)s][%(funcName)s:%(lineno)d][%(levelname)s] : %(message)s'  # 文件日志格式
LOG_CONSOLE_FMT = '[%(asctime)s] %(message)s'  # 控制台日志格式
LOG_DATEFMT = '%Y-%m-%d %H:%M:%S'  # 日期格式
LOG_LEVEL = logging.DEBUG  # 日志级别
LOG_CONSOLE_LEVEL = logging.INFO  # 日志级别
LOG_FILE_LEVEL = logging.DEBUG  # 日志级别


class CustomLog:
    def __init__(self, log_name, file_name):
        """

        :param log_name: 日志别名
        :param file_name: 日志保存的绝对路径
        """
        # 创建日志记录器
        self._logger = logging.getLogger(log_name)
        self._logger.setLevel(LOG_LEVEL)
        # 设置日志格式
        self.file_formatter = logging.Formatter(fmt=LOG_FILE_FMT, datefmt=LOG_DATEFMT)
        self.console_formatter = logging.Formatter(fmt=LOG_CONSOLE_FMT, datefmt=LOG_DATEFMT)
        # 日志控制台输出
        console_handler = logging.StreamHandler()
        console_handler.setFormatter(self.console_formatter)
        console_handler.setLevel(LOG_CONSOLE_LEVEL)
        # 日志文件输出
        file_handler = handlers.RotatingFileHandler(
            # filename=os.path.join(BASE_DIR, LOG_DIR, file_name),
            filename=file_name,
            maxBytes=548576,
            backupCount=10,
            encoding='utf-8'
        )
        file_handler.setFormatter(self.file_formatter)
        file_handler.setLevel(LOG_FILE_LEVEL)
        # 将控制台输出和文件输出添加到日志记录器
        self._logger.addHandler(console_handler)
        self._logger.addHandler(file_handler)

    @property
    def logger(self):
        return self._logger



# -*- coding: utf-8 -*-
# @Author  : isFhy
# @Email   : fhy.sdwh@gmail.com
# @File    : tools.py
# @Time    : 2024/6/7 15:45
# **********************************************

import requests
from datetime import datetime


# 时间格式化
def handle_datetime(timestamp=None, onlyDate=False):
    """

    :param timestamp: 默认None,如果提供时间戳,则由时间戳格式化时间,否则按照当前时间来格式化
    :param onlyDate: 默认False, 格式化为:年月日时分秒, True,则格式化为年月日
    :return:
    """
    if timestamp:
        if len(str(timestamp)) == 13:
            date = datetime.fromtimestamp(timestamp / 1000)
        else:
            date = datetime.fromtimestamp(timestamp)
    else:
        date = datetime.now()
    if onlyDate:
        formatted_date = date.strftime('%Y-%m-%d')
    else:
        formatted_date = date.strftime('%Y-%m-%d %H:%M:%S')
    return formatted_date


def translate_by_google(API_KEY, text: str):
    """

    :param API_KEY: Google翻译的API_KEY
    :param text: 需要进行翻译的英文文本
    :return:
    """
    if text == '' or text is None:
        return ''
    url = 'https://translation.googleapis.com/language/translate/v2'
    params = {
        'q': text,
        'target': 'zh-CN',
        'source': 'en',
        'format': 'text',
        'key': API_KEY
    }
    try:
        resp = requests.get(url=url, params=params, verify=False).json()
        if resp.get('data').get('translations'):
            translatedText = resp['data']['translations'][0].get('translatedText')
            if translatedText:
                return translatedText
            else:
                return '翻译API网络异常,请自行翻译!'
        else:
            return '翻译API网络异常,请自行翻译!'
    except Exception as e:
        return '翻译API网络异常,请自行翻译!'



# -*- coding: utf-8 -*-
# @Author  : isFhy
# @Email   : fhy.sdwh@gmail.com
# @File    : setup.py
# @Time    : 2024/6/7 16:02
# **********************************************

from setuptools import find_packages, setup

setup(
    name='isfhyfp',
    version='1.0.0',
    packages=find_packages(),
    author='isfhy',
    author_email='fhy.sdwh@gmail.com',
    description='个人常用函数及自定义日志类等',
    include_package_data=True,
    license='GNU GPLv3',
    zip_safe=False,
    install_requires=[
        'requests',
    ],
)
